/******************************************************************************
* C Include: Linked_List                                                      *
*                                                                             *
* File:                                                                       *
*    lnkd_lst.h                                                               *
*                                                                             *
* History:                                                                    *
*    Created    : 02-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Description:                                                                *
*    Include file for the Linked_List functions.                              *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#ifndef __LNKD_LST__

#include "generic.h"

/************************
* Linked List constants *
************************/
#define __LNKD_LST__

/*********************************
* Linked List derived data types *
*********************************/
struct Linked_List_Node /* Node in a linked list */
{
   void                    *Data;     /* Pointer to data in linked list node */
   struct Linked_List_Node *Next;     /* Pointer to next node in linked list */
   struct Linked_List_Node *Previous; /* Pointer to previous node in linked
                                       * list.
                                       */
};
typedef struct Linked_List_Node * LL_NODE;

struct Linked_List /* Header for a linked list */
{
   LL_NODE Top;
};
typedef struct Linked_List * LL;

/************************************
* Linked List functions' prototypes *
************************************/
LL       Create_Empty_Linked_List(/* void                  */);

void     Delete_Linked_List      (/* LL       List         */);

void     Delete_Linked_List_Data (/* LL       List        ,
				     void     (*Delete)()  */);

void     Delete_Linked_List_Node (/* LL      List         ,
				     LL_NODE  Node         */);

void     Delete_Linked_List_Nodes(/* LL_NODE  Top_Node     */);

/**********************************
* Linked List include file page 2 *
**********************************/

void    *Find_Linked_List_Data   (/* LL List              ,
				     void    *Data        ,
				     int      (*Compare)() */);
LL_NODE  Find_Linked_List_Node   (/* LL_NODE  First_Node  ,
				     void    *Data        ,
				     int      (*Compare)() */);

void     Insert_Linked_List_Data (/* LL       List        ,
				     void    *Data         */);

BOOL     Linked_List_Is_Empty    (/* LL       List         */);

#endif
